@@ -29,3 +29,21 @@ class MissingFileError(CommandLineError):
             'The file "%(filename)s" can not be found.\n'
             'Is this the right path/to/file/you/want/to/extract%(ext)s?'
         ))
+
+
+class UnknownMethod(CommandLineError):
+    def __init__(self, method):
+        self.method = method
+
+    def __str__(self):
+        return self.render((
+            'The method "%(method)s" can not be found for this filetype.'
+        ))
+
+
+class ShellError(CommandLineError):
+    def __init__(self, exit_code):
+        self.exit_code = exit_code
+
+    def __str__(self):
+        return "Command failed with exit code %s" % self.exit_code
